@@ -24,6 +24,7 @@
 import ast
 import base64
 import collections
+from enum import Enum
 import importlib
 import inspect
 import logging
@@ -38,9 +39,8 @@ from dlg import droputils, utils
 from dlg.drop import BarrierAppDROP
 from dlg.exceptions import InvalidDropException
 from dlg.meta import (
-    dlg_bool_param,
     dlg_string_param,
-    dlg_float_param,
+    dlg_enum_param,
     dlg_dict_param,
     dlg_component,
     dlg_batch_input,
@@ -104,13 +104,21 @@ def import_using_name(app, fname):
             )
         except AttributeError:
             raise InvalidDropException(app, "Module %s has no member %s" % (modname, fname))
-    
+
 
 
 def import_using_code(code):
     return dill.loads(code)
 
 
+class DropParser(Enum):
+    PICKLE = 'pickle'
+    EVAL = 'eval'
+    NPY = 'npy'
+    #JSON = "json"
+    PATH = 'path'  # input only
+    DATAURL = 'dataurl'  # input only
+
 ##
 # @brief PyFuncApp
 # @details An application that wraps a simple python function.
@@ -138,8 +146,10 @@ def import_using_code(code):
 #     \~English Python function name
 # @param[in] aparam/func_code Function Code//String/readwrite/False//False/
 #     \~English Python function code, e.g. 'def function_name(args): return args'
-# @param[in] aparam/pickle Pickle/false/Boolean/readwrite/False//False/
-#     \~English Whether the python arguments are pickled.
+# @param[in] aparam/input_parser Input Parser/pickle/Select/readwrite/False/pickle,eval,npy,path,dataurl/False/
+#     \~English Input port parsing technique
+# @param[in] aparam/output_parser Output Parser/pickle/Select/readwrite/False/pickle,eval,npy/False/
+#     \~English output port parsing technique
 # @param[in] aparam/func_defaults Function Defaults//String/readwrite/False//False/
 #     \~English Mapping from argname to default value. Should match only the last part of the argnames list.
 #               Values are interpreted as Python code literals and that means string values need to be quoted.
@@ -193,15 +203,11 @@ class PyFuncApp(BarrierAppDROP):
     )
 
     func_name = dlg_string_param("func_name", None)
-
     # func_code = dlg_bytes_param("func_code", None) # bytes or base64 string
-
-    pickle = dlg_bool_param("pickle", True)
-
+    input_parser: DropParser = dlg_enum_param(DropParser, "input_parser", DropParser.PICKLE)  # type: ignore
+    output_parser: DropParser = dlg_enum_param(DropParser, "output_parser", DropParser.PICKLE)  # type: ignore
     func_arg_mapping = dlg_dict_param("func_arg_mapping", {})
-
     func_defaults = dlg_dict_param("func_defaults", {})
-
     f: Callable
     fdefaults: dict
 
@@ -231,11 +237,11 @@ class PyFuncApp(BarrierAppDROP):
         # we came all this way, now assume that any resulting dict is correct
         if not isinstance(self.func_defaults, dict):
             logger.error(
-                f"Wrong format or type for function defaults for "
-                + "{self.f.__name__}: {self.func_defaults}, {type(self.func_defaults)}"
+                "Wrong format or type for function defaults for %s: %r, %r",
+                self.f.__name__, self.func_defaults, type(self.func_defaults)
             )
             raise ValueError
-        if self.pickle:
+        if self.input_parser is DropParser.PICKLE:
             # only values are pickled, get them unpickled
             for name, value in self.func_defaults.items():
                 self.func_defaults[name] = deserialize_data(value)
@@ -284,27 +290,31 @@ class PyFuncApp(BarrierAppDROP):
             "func_code",
             "func_name",
             "func_arg_mapping",
+            "input_parser",
+            "output_parser",
+            "func_defaults",
             "pickle",
-            "func_defaults"
             ]
+
+        # backwards compatibility
+        if "pickle" in self._applicationArgs:
+            if self._applicationArgs["pickle"]["value"] == True:
+                self.input_parser = DropParser.PICKLE
+                self.output_parser = DropParser.PICKLE
+            else:
+                self.input_parser = DropParser.EVAL
+                self.output_parser = DropParser.EVAL
+            self._applicationArgs.pop("pickle")
+
         for kw in self.func_def_keywords:
-            dum_arg = new_arg = "gIbbERiSH:askldhgol"
             if kw in self._applicationArgs:  # these are the preferred ones now
                 if isinstance(
                     self._applicationArgs[kw]["value"], bool
-                ):  # always transfer booleans
-                    new_arg = self._applicationArgs.pop(kw)
-                elif (
-                    self._applicationArgs[kw]["value"]
+                    or self._applicationArgs[kw]["value"]
                     or self._applicationArgs[kw]["precious"]
                 ):
                     # only transfer if there is a value or precious is True
-                    new_arg = self._applicationArgs.pop(kw)
-
-            if new_arg != dum_arg:
-                logger.debug(f"Setting {kw} to {new_arg['value']}")
-                # we allow python expressions as values, means that strings need to be quoted
-                self.__setattr__(kw, new_arg["value"])
+                    self._applicationArgs.pop(kw)
 
         self.num_args = len(
             self._applicationArgs
@@ -363,7 +373,7 @@ class PyFuncApp(BarrierAppDROP):
         Function arguments in Python can be passed as positional, kw-value, positional
         only, kw-value only, and catch-all args and kwargs, which don't provide any
         hint about the names of accepted parameters. All of them are now supported. If
-        positional arguments or kw-value arguments are provided by the user, but are 
+        positional arguments or kw-value arguments are provided by the user, but are
         not explicitely defined in the function signiture AND args and/or kwargs are
         allowed then these arguments are passed to the function. For args this is
         somewhat risky, since the order is relevant and in this code derived from the
@@ -381,20 +391,33 @@ class PyFuncApp(BarrierAppDROP):
 
         # Inputs are un-pickled and treated as the arguments of the function
         # Their order must be preserved, so we use an OrderedDict
-        if self.pickle:
-            all_contents = lambda x: pickle.loads(x)
+        if self.input_parser is DropParser.PICKLE:
+            #all_contents = lambda x: pickle.loads(droputils.allDropContents(x))
+            all_contents = droputils.load_pickle
+        elif self.input_parser is DropParser.EVAL:
+            def optionalEval(x):
+                # Null and Empty Drops will return an empty byte string
+                # which should propogate back to None
+                content: str = droputils.allDropContents(x).decode('utf-8')
+                return ast.literal_eval(content) if len(content) > 0 else None
+            all_contents = optionalEval
+        elif self.input_parser is DropParser.NPY:
+            all_contents = droputils.load_npy
+        elif self.input_parser is DropParser.PATH:
+            all_contents = lambda x: x.path
+        elif self.input_parser is DropParser.DATAURL:
+            all_contents = lambda x: x.dataurl
         else:
-            all_contents = lambda x: ast.literal_eval(
-                droputils.allDropContents(x).decode("utf-8")
-            )
+            raise ValueError(self.input_parser.__repr__())
 
         inputs = collections.OrderedDict()
         for uid, drop in self._inputs.items():
-            contents = droputils.allDropContents(drop)
-            # allow for Null DROPs to be passed around
-            inputs[uid] = all_contents(contents) if contents else None
+            inputs[uid] = all_contents(drop)
+
+        outputs = collections.OrderedDict()
+        for uid, drop in self._outputs.items():
+            outputs[uid] = all_contents(drop) if self.output_parser is DropParser.PATH else None
 
-        self.funcargs = {}
 
         # Keyword arguments are made up of the default values plus the inputs
         # that match one of the keyword argument names
@@ -410,7 +433,7 @@ class PyFuncApp(BarrierAppDROP):
             if name in self.func_defaults or name not in argnames
         }
         logger.debug(f"updating funcargs with {kwargs}")
-        self.funcargs = kwargs
+        funcargs = kwargs
 
         # Fill arguments with rest of inputs
         logger.debug(f"available inputs: {inputs}")
@@ -420,57 +443,87 @@ class PyFuncApp(BarrierAppDROP):
         logger.debug(f"Parameters found: {self.parameters}")
         posargs = self.arguments.args[:self.fn_npos]
         kwargs = {}
-        self.pargs = []
-        pargsDict = collections.OrderedDict(zip(posargs,[None]*len(posargs)))  # Initialize pargs dictionary
+        pargs = []
+        # Initialize pargs dictionary and update with provided argument values
+        pargsDict = collections.OrderedDict(zip(posargs,[None]*len(posargs)))
+        if "applicationArgs" in self.parameters:
+            appArgs = self.parameters["applicationArgs"]  # we'll pop the identified ones
+            pargsDict.update({k:self.parameters[k] for k in pargsDict if k in 
+                self.parameters})
+            # if defined in both we use AppArgs values
+            pargsDict.update({k:appArgs[k]['value'] for k in pargsDict if k 
+                in appArgs})
+            logger.debug("Initial posargs dictionary: %s", pargsDict)
+        else:
+            appArgs = {}
+
         if ('inputs' in self.parameters and isinstance(self.parameters['inputs'][0], dict)):
-            logger.debug(f"Using named ports to identify inputs: "+\
-                    f"{self.parameters['inputs']}")
-            for i in range(min(len(inputs),self.fn_nargs +\
-                len(self.arguments.kwonlyargs))):
-                # key for final dict is value in named ports dict
-                key = list(self.parameters['inputs'][i].values())[0]
-                # value for final dict is value in inputs dict
-                value = inputs[list(self.parameters['inputs'][i].keys())[0]]
-                if key in posargs:
-                    pargsDict.update({key:value})
-                else:
-                    kwargs.update({key:value})
+            check_len = min(len(inputs),self.fn_nargs+
+                len(self.arguments.kwonlyargs))
+            kwargs.update(droputils.identify_named_ports(
+                inputs,
+                self.parameters['inputs'],
+                posargs,
+                pargsDict,
+                appArgs,
+                check_len=check_len,
+                mode="inputs"))
         else:
             for i in range(min(len(inputs),self.fn_nargs)):
                 kwargs.update({self.arguments.args[i]: list(inputs.values())[i]})
 
-        logger.debug(f"updating funcargs with input ports {kwargs}")
-        self.funcargs.update(kwargs)
+        logger.debug(f"Updating funcargs with input ports {kwargs}")
+        funcargs.update(kwargs)
+
+        if ('outputs' in self.parameters and isinstance(self.parameters['outputs'][0], dict)):
+            check_len = min(len(outputs),self.fn_nargs+
+                len(self.arguments.kwonlyargs))
+            kwargs.update(droputils.identify_named_ports(
+                outputs,
+                self.parameters['outputs'],
+                posargs,
+                pargsDict,
+                appArgs,
+                check_len=check_len,
+                mode="outputs"))
 
         # Try to get values for still missing positional arguments from Application Args
         if "applicationArgs" in self.parameters:
-            appArgs = self.parameters["applicationArgs"]  # we'll pop them
             _dum = [appArgs.pop(k) for k in self.func_def_keywords if k in appArgs]
+            logger.debug("Identified keyword arguments removed: %s",
+                [i['text'] for i in _dum])
             for pa in posargs:
-                if pa not in self.funcargs:
-                    if pa in appArgs and pa != 'self':
+                if pa != 'self' and pa not in funcargs:
+                    if pa in appArgs:
                         arg = appArgs.pop(pa)
                         value = arg['value']
                         ptype = arg['type']
                         if ptype in ["Complex", "Json"]:
                             try:
                                 value = ast.literal_eval(value)
+                            except Exception as e:
+                                # just go on if this did not work
+                                logger.warning("Eval raised an error: %s",e)
+                        elif ptype in ["Python"]:
+                            try:
+                                import numpy
+                                value = eval(value, {"numpy": numpy}, {})
                             except:
                                 pass
-                        pargsDict.update({
-                            pa:
-                            value
-                        })
+                        pargsDict.update({pa: value})
                     elif pa != 'self' and pa not in pargsDict:
                         logger.warning(f"Required positional argument '{pa}' not found!")
-            logger.debug(f"updating posargs with {list(pargsDict.values())}")
-            self.pargs.extend(list(pargsDict.values()))
+            _dum = [appArgs.pop(k) for k in pargsDict if k in appArgs]
+            logger.debug("Identified positional arguments removed: %s", 
+                [i['text'] for i in _dum])
+            logger.debug(f"updating posargs with {list(pargsDict.keys())}")
+            pargs.extend(list(pargsDict.values()))
 
             # Try to get values for still missing kwargs arguments from Application kws
             kwargs = {}
             kws = self.arguments.args[self.fn_npos:]
             for ka in kws:
-                if ka not in self.funcargs:
+                if ka not in funcargs:
                     if ka in appArgs:
                         arg = appArgs.pop(ka)
                         value = arg['value']
@@ -487,7 +540,32 @@ class PyFuncApp(BarrierAppDROP):
                     else:
                         logger.warning(f"Keyword argument '{ka}' not found!")
             logger.debug(f"updating funcargs with {kwargs}")
-            self.funcargs.update(kwargs)
+            funcargs.update(kwargs)
+
+            # deal with kwonlyargs
+            kwargs = {}
+            kws = self.arguments.kwonlyargs
+            for ka in kws:
+                if ka not in funcargs:
+                    if ka in appArgs:
+                        arg = appArgs.pop(ka)
+                        value = arg['value']
+                        ptype = arg['type']
+                        if ptype in ["Complex", "Json"]:
+                            try:
+                                value = ast.literal_eval(value)
+                            except:
+                                pass
+                        kwargs.update({
+                            ka:
+                            value
+                        })
+                    else:
+                        logger.warning(f"Keyword only argument '{ka}' not found!")
+            logger.debug(f"updating funcargs with kwonlyargs: {kwargs}")
+            funcargs.update(kwargs)
+
+            # any remaining application arguments will be used for vargs and vkwargs
             vparg = []
             vkarg = {}
             logger.debug(f"Remaining AppArguments {appArgs}")
@@ -501,27 +579,26 @@ class PyFuncApp(BarrierAppDROP):
                 else:
                     vkarg.update({arg:value})
 
-            # any remaining application arguments will be used for vargs and vkwargs
             if self.arguments.varargs:
-                self.pargs.extend(vparg)
+                pargs.extend(vparg)
             if self.arguments.varkw:
-                self.funcargs.update(vkarg)
+                funcargs.update(vkarg)
 
         # Fill rest with default arguments if there are any more
         kwargs = {}
         for kw in self.func_defaults.keys():
             value = self.func_defaults[kw]
-            if kw not in self.funcargs:
+            if kw not in funcargs:
                 kwargs.update({kw: value})
         logger.debug(f"updating funcargs with {kwargs}")
-        self.funcargs.update(kwargs)
-        self._recompute_data["args"] = self.funcargs.copy()
-        logger.debug(f"Running {self.func_name} with *{self.pargs} **{self.funcargs}")
+        funcargs.update(kwargs)
+        self._recompute_data["args"] = funcargs.copy()
+        logger.debug(f"Running {self.func_name} with *{pargs} **{funcargs}")
 
         # we capture and log whatever is produced on STDOUT
         capture = StringIO()
         with redirect_stdout(capture):
-            result = self.f(*self.pargs, **self.funcargs)
+            result = self.f(*pargs, **funcargs)
         logger.info(f"Captured output from function app '{self.func_name}': {capture.getvalue()}")
         logger.debug(f"Finished execution of {self.func_name}.")
 
@@ -536,12 +613,15 @@ class PyFuncApp(BarrierAppDROP):
             if len(outputs) == 1:
                 result = [result]
             for r, o in zip(result, outputs):
-                p = pickle.dumps(r)
-                if self.pickle:
+                if self.output_parser is DropParser.PICKLE:
                     logger.debug(f"Writing pickeled result {type(r)} to {o}")
-                    o.write(pickle.dumps(r))  # @UndefinedVariable
+                    o.write(pickle.dumps(r))
+                elif self.output_parser is DropParser.EVAL:
+                    o.write(repr(r).encode('utf-8'))
+                elif self.output_parser is DropParser.NPY:
+                    droputils.save_npy(o, r)
                 else:
-                    o.write(repr(r).encode("utf-8"))
+                    ValueError(self.output_parser.__repr__())
 
     def generate_recompute_data(self):
         return self._recompute_data
