@@ -35,7 +35,6 @@ import sys
 import threading
 import time
 
-from glob import glob
 from . import constants
 from .drop_manager import DROPManager
 from .session import Session
@@ -128,7 +127,9 @@ class NodeManagerBase(DROPManager):
 
     def __init__(
         self,
-        useDLM=False,
+        dlm_check_period=0,
+        dlm_cleanup_period=0,
+        dlm_enable_replication=False,
         dlgPath=None,
         error_listener=None,
         event_listeners=[],
@@ -136,7 +137,11 @@ class NodeManagerBase(DROPManager):
         logdir=utils.getDlgLogsDir(),
     ):
 
-        self._dlm = DataLifecycleManager() if useDLM else None
+        self._dlm = DataLifecycleManager(
+            check_period=dlm_check_period,
+            cleanup_period=dlm_cleanup_period,
+            enable_drop_replication=dlm_enable_replication
+        )
         self._sessions = {}
         self.logdir = logdir
 
@@ -181,39 +186,16 @@ class NodeManagerBase(DROPManager):
         debugging = logger.isEnabledFor(logging.DEBUG)
         self._logging_event_listener = LogEvtListener() if debugging else None
 
-        # Start the mix-ins
-        self.start()
-
-    @abc.abstractmethod
     def start(self):
-        """
-        Starts any background task required by this Node Manager
-        """
+        super().start()
+        self._dlm.startup()
 
-    @abc.abstractmethod
     def shutdown(self):
-        """
-        Stops any pending background task run by this Node Manager
-        """
-
-    @abc.abstractmethod
-    def subscribe(self, host, port):
-        """
-        Subscribes this Node Manager to events published in from ``host``:``port``
-        """
-
-    @abc.abstractmethod
-    def publish_event(self, evt):
-        """
-        Publishes the event ``evt`` for other Node Managers to receive it
-        """
-
-    @abc.abstractmethod
-    def get_rpc_client(self, hostname, port):
-        """
-        Creates an RPC client connected to the node manager running in
-        ``host``:``port``, and its closing method, as a 2-tuple.
-        """
+        self._dlm.cleanup()
+        if self._threadpool:
+            self._threadpool.close()
+            self._threadpool.join()
+        super().shutdown()
 
     def deliver_event(self, evt):
         """
@@ -222,8 +204,8 @@ class NodeManagerBase(DROPManager):
         """
         if not evt.session_id in self._sessions:
             logger.warning(
-                "No session %s found, event (%s) will be dropped"
-                % (evt.session_id, evt.type)
+                "No session %s found, event (%s) will be dropped",
+                evt.session_id, evt.type
             )
             return
         self._sessions[evt.session_id].deliver_event(evt)
@@ -288,8 +270,7 @@ class NodeManagerBase(DROPManager):
                     )
                 drop._sessID = sessionId
                 self._memoryManager.register_drop(drop.uid, sessionId)
-            if self._dlm:
-                self._dlm.addDrop(drop)
+            self._dlm.addDrop(drop)
 
             # Remote event forwarding
             evt_listener = NMDropEventListener(self, sessionId)
@@ -326,6 +307,7 @@ class NodeManagerBase(DROPManager):
         session = self._sessions.pop(sessionId)
         if hasattr(self, "_memoryManager"):
             self._memoryManager.shutdown_session(sessionId)
+        self._dlm.remove_drops(session.drops)
         session.destroy()
 
     def getSessionIds(self):
@@ -374,11 +356,6 @@ class NodeManagerBase(DROPManager):
         self._check_session_id(sessionId)
         return self._sessions[sessionId].call_drop(uid, method, *args)
 
-    def shutdown(self):
-        if hasattr(self, "_threadpool") and self._threadpool is not None:
-            self._threadpool.close()
-            self._threadpool.join()
-
 
 class ZMQPubSubMixIn(object):
     """
@@ -568,28 +545,26 @@ class RpcMixIn(rpc.RPCClient, rpc.RPCServer):
 
 
 # Final NodeManager class
-class NodeManager(EventMixIn, RpcMixIn, NodeManagerBase):
+class NodeManager(NodeManagerBase, EventMixIn, RpcMixIn):
     def __init__(
         self,
-        useDLM=True,
-        dlgPath=utils.getDlgPath(),
-        error_listener=None,
-        event_listeners=[],
-        max_threads=0,
-        logdir=utils.getDlgLogsDir(),
         host=None,
         rpc_port=constants.NODE_DEFAULT_RPC_PORT,
         events_port=constants.NODE_DEFAULT_EVENTS_PORT,
+        *args,
+        **kwargs
     ):
+        host = host or "127.0.0.1"
+        NodeManagerBase.__init__(self, *args, **kwargs)
+        EventMixIn.__init__(self, host, events_port)
+        RpcMixIn.__init__(self, host, rpc_port)
+        self.start()
+
+    def start(self):
         # We "just know" that our RpcMixIn will have a create_context static
         # method, which in reality means we are using the ZeroRPCServer class
         self._context = RpcMixIn.create_context()
-        host = host or "127.0.0.1"
-        EventMixIn.__init__(self, host, events_port)
-        RpcMixIn.__init__(self, host, rpc_port)
-        NodeManagerBase.__init__(
-            self, useDLM, dlgPath, error_listener, event_listeners, max_threads, logdir
-        )
+        super().start()
 
     def shutdown(self):
         super(NodeManager, self).shutdown()
